pub struct CacheSource<T, S: CacheReplayer<T>> { /* private fields */ }Trait Implementations
Sourceimpl<T: Clone, S: CacheReplayer<T>> Clone for CacheSource<T, S>
impl<T: Clone, S: CacheReplayer<T>> Clone for CacheSource<T, S>
Sourceimpl<T, S: CacheReplayer<T>> Display for CacheSource<T, S>
impl<T, S: CacheReplayer<T>> Display for CacheSource<T, S>
Sourceimpl<T: Data, S: CacheReplayer<T> + Send> Operator for CacheSource<T, S>
impl<T: Data, S: CacheReplayer<T> + Send> Operator for CacheSource<T, S>
type Out = T
Sourcefn setup(&mut self, metadata: &mut ExecutionMetadata<'_>)
fn setup(&mut self, metadata: &mut ExecutionMetadata<'_>)
Setup the operator chain. This is called before any call to
next and it’s used to
initialize the operator. When it’s called the operator has already been cloned and it will
never be cloned again. Therefore it’s safe to store replica-specific metadata inside of it. Read moreSourcefn next(&mut self) -> StreamElement<T>
fn next(&mut self) -> StreamElement<T>
Take a value from the previous operator, process it and return it.
Sourcefn structure(&self) -> BlockStructure
fn structure(&self) -> BlockStructure
A more refined representation of the operator and its predecessors.
Sourceimpl<T: Clone + Send + 'static, S: CacheReplayer<T>> Source for CacheSource<T, S>
impl<T: Clone + Send + 'static, S: CacheReplayer<T>> Source for CacheSource<T, S>
Sourcefn replication(&self) -> Replication
fn replication(&self) -> Replication
The maximum parallelism offered by this operator.